@@ -12,6 +12,7 @@
 
 #include <QInputDialog>
 
+#include <KAuthorized>
 #include <KEditListWidget>
 #include <KMessageBox>
 #include <KMessageWidget>
@@ -99,6 +100,8 @@ namespace Konversation
         m_loginEdit->setValidator(validator);
         m_nicknameLBox->lineEdit()->setValidator(validator);
 
+        m_authPasswordEdit->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+
         // set values for the widgets
         updateIdentity(0);
 
