@@ -1,23 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
-*/
-
-/*
-  Copyright (C) 2012 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
 */
 
 #include "topichistorymodel.h"
@@ -25,14 +9,13 @@
 #include "cipher.h"
 #endif
 
-#include <KCategorizedSortFilterProxyModel>
 #include <QLocale>
 
 
 TopicHistoryModel::TopicHistoryModel(QObject* parent) : QAbstractListModel(parent)
 {
 #ifdef HAVE_QCA2
-    m_cipher = 0;
+    m_cipher = nullptr;
 #endif
 }
 
@@ -46,7 +29,7 @@ QString TopicHistoryModel::authorPlaceholder()
 }
 
 
-QString TopicHistoryModel::currentTopic()
+QString TopicHistoryModel::currentTopic() const
 {
     if (m_topicList.isEmpty())
         return QString();
@@ -54,7 +37,7 @@ QString TopicHistoryModel::currentTopic()
     return data(index(m_topicList.count() - 1, 0)).toString();
 }
 
-void TopicHistoryModel::appendTopic(const QString& text, const QString& author, QDateTime timestamp)
+void TopicHistoryModel::appendTopic(const QString& text, const QString& author, const QDateTime &timestamp)
 {
     int newIndex = m_topicList.count();
 
@@ -80,10 +63,10 @@ void TopicHistoryModel::appendTopic(const QString& text, const QString& author,
 
     endInsertRows();
 
-    currentTopicChanged(text);
+    emit currentTopicChanged(text);
 }
 
-void TopicHistoryModel::setCurrentTopicMetadata(const QString& author, QDateTime timestamp)
+void TopicHistoryModel::setCurrentTopicMetadata(const QString& author, const QDateTime &timestamp)
 {
     if (m_topicList.isEmpty())
         return;
@@ -124,7 +107,7 @@ void TopicHistoryModel::clearCipher()
     emit layoutAboutToBeChanged();
     beginResetModel();
 
-    m_cipher = 0;
+    m_cipher = nullptr;
 
     endResetModel();
     emit layoutChanged();
@@ -202,14 +185,14 @@ QVariant TopicHistoryModel::headerData(int section, Qt::Orientation orientation,
 
 int TopicHistoryModel::columnCount(const QModelIndex& parent) const
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
 
     return 3;
 }
 
 int TopicHistoryModel::rowCount(const QModelIndex& parent) const
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
 
     return m_topicList.count();
 }
